import java.io.File;
import java.io.FileFilter;
import java.util.Locale;

import com.cs.util.LicenseUtil;
import com.spire.xls.CellRange;
import com.spire.xls.CellStyle;
import com.spire.xls.FileFormat;
import com.spire.xls.PageSetup;
import com.spire.xls.Workbook;
import com.spire.xls.Worksheet;

public class MainSpireOfcDocument {

	public static void main(String[] args) {
	    
	    String srcPath = "E:\\Files";
	    String outputPath = "E:\\Files\\pdf";
	    String outputFileFormat = "pdf";
	    
	    try {

			// Apply license key only on application startup
			LicenseUtil.applyApiLicense();
	    	System.out.println("Applied Spire.Office license");
			
//			// Set culture-name
//			Locale locale = new Locale("zh", "CN");
//	        Locale.setDefault(locale);
//	        System.out.println("Set culture-name");
	        
	        // Convert excel files into pdf
	        System.out.println("---------------- Excel to PDF conversion START -------------------");
	        doConversion(srcPath, outputPath, outputFileFormat);
	        System.out.println("----------------- Excel to PDF conversion END ------------------");
	        
	    } catch (Exception e) {
	    	e.printStackTrace();
	    }
	}
    
    public static void doConversion(String srcPath, String outputPath, String outputFileFormat) {
    	
        String outputFileName = "";
        
        File[] files = new File(srcPath).listFiles(new FileFilter() {

            @Override
            public boolean accept(File pathname) {
                if (pathname.getName().endsWith(".xlsx") || pathname.getName().endsWith(".xls")) {
                    return true;
                }
                return false;
            }
        });
        
        try {
        
	        for (File file : files) {
	            
	            outputFileName = getOutputPath(outputPath + "\\" + file.getName(), outputFileFormat);
	        	
	            Workbook workbook = new Workbook();
	            workbook.loadFromFile(file.getPath());
	            workbook.getConverterSetting().setSheetFitToWidth(true);
//	            workbook.getConverterSetting().setSheetFitToPage(false);
	            workbook.getConverterSetting().isReCalculateOnConvert(true);
	            
	            for (int i = 0; i < workbook.getWorksheets().size(); i++) {
	            	
	                Worksheet worksheet = workbook.getWorksheets().get(i);
	                
	                if (worksheet.getPivotTables().getCount() == 0) {
	                    worksheet.CalculateAllValue();
	                }
	
	                setShrinkUnwrapCells(worksheet, true, false);
	                setAutoFitValues(worksheet);
	                setPrintPageSetup(worksheet);
	            }
	            workbook.saveToFile(outputFileName, FileFormat.PDF);
	        	workbook.dispose();
	        	System.out.println("Processed file ::: "+file.getName());
	        }
        } catch (Exception e) {
			e.printStackTrace();
		}
    }
    
    // To form pdf file name from excel file
    public static String getOutputPath(String sourcePath, String fileFormat) {
    	
        int index = sourcePath.lastIndexOf(".");
        String path = sourcePath.substring(0, ++index);
        return path + fileFormat;
    }
    
    // To fit the multiple lines of data in a single cell
    public static void setAutoFitValues(Worksheet worksheet) {
    	
    	Boolean isMerged = false;

        CellRange[] rows = worksheet.getRows();
        
        for (int r = 0; r < rows.length; r++) {
            if (rows[r].hasMerged()) {
            	isMerged = true;
                break;
            }
        }
        if (isMerged) {
            worksheet.getAllocatedRange().autoFitColumns();
        }
        if (!isMerged) {
            worksheet.getAllocatedRange().autoFitColumns();
            worksheet.getAllocatedRange().autoFitRows();
        }
    }
    
    // To shrink the content within a cell
    public static void setShrinkUnwrapCells(Worksheet worksheet, boolean isShrink, boolean isWrap) {
    	
    	for (int col = worksheet.getFirstColumn(); col <= worksheet.getLastColumn(); col++){
//            CellStyle style = worksheet.getColumns()[col-1].getCellStyle();
            CellStyle style = worksheet.getDefaultColumnStyle(col);
            style.setShrinkToFit(isShrink);
            style.setWrapText(isWrap);
        }
    	
//    	CellRange cellRange = worksheet.getAllocatedRange();
//    	cellRange.getCellStyle().setShrinkToFit(isShrink);
    }
    
    // To set page print section
    public static void setPrintPageSetup(Worksheet worksheet) {
    	
    	PageSetup pageSetup = worksheet.getPageSetup();
        pageSetup.setPrintArea(null);
    }
}
